Sidney Phillips : Register to: buy a Pub in England, buy a Pub in Wales, Pubs, Hotels, Restaurants for sale
Author: Sidney Phillips
Description: UK based licensed business agents offering pubs for sale and other licensed premises including night clubs and discos. Properties include urban pubs and roadside inns.
Keywords: pubs for sale, commercial letting agents, uk, freeholds, leaseholds, tenancies, public houses, licensed premises, discos, clubs, inns, taverns, rural, urban, city centre, locations, sales, transfers

accessibility | skip nav
Home | Login | Register
08454 585 900
Search for information
or
Property Quick Search

# Register

Click here if you have forgotten your password

* indicates a required field.

Personal information
Title *
Initials *
Surname *
Honours
Company
Address information
Postcode * (UK only)
Unit/Prefix
Building
Street No.
Street #1 *
Street #2
Suburb
Town
County
Country
Contact information
Telephone day *
Telephone night
Telephone mobile
Email *
How did you find us?
How did you find us?
Search Engine
Previous Visitor
Recommendation
Website link
Daltonâs Weekly
Morning Advisor
Publican
Other
Additional information
Registration requirements
Register to receive, by post, business summaries and updates
Email me when the Website businesses are updated or properties match my requirements
Min Price
Numbers only (no pound, comma or decimal point please)
Max Price
Numbers only (no pound, comma or decimal point please)
Region or county
select multiple regions by holding control and clicking the required regions
Tenure
Freehold
Leasehold
Special requirements
Acceptance of Terms and conditions
I accept the Terms and conditions